﻿# -*- coding: utf-8 -*-

from brownie import *
import imp, sys, os

__cache = {}

def __quote(items):
    for i in items:
        path = i.path
        if path.find(' ') >= 0:
            yield '"' + path + '"'
        else:
            yield path

def __selection(view):
    items = view.selection
    if items:
        return ' '.join([i for i in __quote(items)])
    else:
        return None

def load(name):
    try:
        path = Path(os.path.join(config.PATH_TOOLS, name + '.lnk'))
        return lambda view: path.execute(argv=__selection(view), dir=view.path)
    except IOError:
        pass
    components = name.split('.')
    module = __import__(components[0])
    if components[-1].endswith('()'):
        components[-1] = components[-1][:-2] # remove trailing '()'
    else:
        components.append('execute')
    for c in components[1:]:
        module = getattr(module, c)
    return module

def execute(view, name, *args):
    try:
        fn = __cache[name]
    except KeyError:
        __cache[name] = fn = load(name)
    try:
        message = fn(view, *args)
        if isinstance(message, tuple) or isinstance(message, list):
            view.root.notify(message[0], message[1])
        elif message:
            view.root.notify(message)
    except Exception:
        # Python 2.5 only accepts "except Exception, e" and
        # Python 3.0 only accepts "except Exception as e".
        # User brownie.exception() for compatibility.
        view.root.notify(exception(), ERROR)
