﻿# -*- coding: utf-8 -*-

from brownie import *
from keymap import *
from nodes import *
from functools import *
import extension
import os

#=============================================================================
# etc
#=============================================================================

def openfile(self):
    dlg = FileDialog()
    path = dlg.run()
    if path:
        self.open(path)

def each_property(self):
    items = self.selection
    for item in items:
        self.select(item)
        self.press(KEY_ENTER, ALT)
    self.select(items)

def enum_toolbox(self):
    index = 0
    for i in os.listdir(config.PATH_TOOLS):
        cut = i.find('.lnk')
        if cut > 0:
            path = Path(os.path.join(config.PATH_TOOLS, i))
            base = i[:cut]
            if index < 36:
                name = '*%s: %s' % ('1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZ'[index], base)
            else:
                name = base
            index += 1
            yield Item(name, partial(extension.execute, self, base), icon = path.icon)

def toolbox(self):
    popup([i for i in enum_toolbox(self)], where = self)

#=============================================================================
# keymap
#=============================================================================

def global_keymap():
    return Keymap({
        ('無変換', 0        ): lambda: System.activate(+1),
        (KEY_X   , WIN      ): lambda: System.activate(+1),
        (KEY_X   , WIN|SHIFT): lambda: System.activate(-1),
    })

def form_keymap(self):
    return Keymap({
        (KEY_TAB, 0            ): lambda: self.activate(EAST),
        (KEY_TAB, SHIFT        ): lambda: self.activate(WEST),
        (KEY_O  , CONTROL      ): lambda: openfile(self),
        (KEY_Q  , CONTROL      ): self.close,
    })

def explorer_keymap(self):
    return Keymap({
        (KEY_ESCAPE   , 0            ): lambda: self.select(None),
        (KEY_ENTER    , ALT          ): lambda: self.press(KEY_ENTER, ALT),
        (KEY_ENTER    , ALT|SHIFT    ): lambda: each_property(self),
        (KEY_BACKSPACE, 0            ): lambda: self.open(FOLDER_PARENT),
        (KEY_BACKSPACE, CONTROL      ): lambda: self.open(FOLDER_PARENT),
        (KEY_DELETE   , 0            ): self.delete,
        (KEY_DELETE   , SHIFT        ): self.bury,
        (KEY_F2       , 0            ): self.rename,
        (KEY_F5       , 0            ): self.refresh,
        (KEY_A        , CONTROL      ): lambda: self.select(-1),
        (KEY_B        , CONTROL      ): lambda: self.selection.execute('C:/bin/MangaMeeya/MangaMeeya.exe'),
        (KEY_B        , SHIFT        ): lambda: extension.execute(self, 'cmd'),
        (KEY_C        , CONTROL      ): self.copy,
        (KEY_C        , CONTROL|SHIFT): self.copy_name,
        (KEY_C        , CONTROL|ALT  ): self.copy_path,
        (KEY_D        , CONTROL      ): self.delete,
        (KEY_D        , CONTROL|SHIFT): self.bury,
        (KEY_E        , CONTROL      ): self.rename,
        (KEY_N        , CONTROL      ): lambda: extension.execute(self, 'select.new()'),
        (KEY_N        , SHIFT        ): self.new,
        (KEY_R        , CONTROL      ): self.refresh,
        (KEY_S        , CONTROL      ): lambda: extension.execute(self, 'select.pattern()'),
        (KEY_S        , SHIFT        ): lambda: extension.execute(self, 'select.regex()'),
        (KEY_T        , CONTROL      ): lambda: toolbox(self),
        (KEY_U        , CONTROL      ): lambda: extension.execute(self, 'extract.url()'),
        (KEY_V        , CONTROL      ): self.paste,
        (KEY_W        , CONTROL      ): self.close,
        (KEY_X        , CONTROL      ): self.cut,
        (KEY_Z        , CONTROL      ): self.undo,
    })

def editor_keymap(self):
    return Keymap({
        (KEY_F2, 0     ): self.select_basename,
        (KEY_F3, 0     ): self.select_extension,
        (KEY_A, CONTROL): lambda: self.press(KEY_HOME),
        (KEY_B, CONTROL): lambda: self.press(KEY_LEFT),
        (KEY_D, CONTROL): lambda: self.press(KEY_DELETE),
        (KEY_E, CONTROL): lambda: self.press(KEY_END),
        (KEY_F, CONTROL): lambda: self.press(KEY_RIGHT),
        (KEY_G, CONTROL): self.select_basename,
        (KEY_K, CONTROL): self.delete_after,
        (KEY_T, CONTROL): self.select_extension,
        (KEY_U, CONTROL): self.delete_before,
    })

#=============================================================================
# gesture
#=============================================================================

def form_gesture(self):
    pass

def explorer_gesture(self):
    return Keymap({
         (BUTTON_L  , RBUTTON          , ()): lambda: self.open(FOLDER_PARENT),
         (BUTTON_L  , RBUTTON | CONTROL, ()): lambda: self.open(FOLDER_PARENT),
         (BUTTON_R  , LBUTTON          , ()): lambda: self.open(FOLDER_PARENT),
         (BUTTON_R  , LBUTTON | CONTROL, ()): lambda: self.open(FOLDER_PARENT),
         (BUTTON_LL , 0                , ()): lambda: self.open(FOLDER_PARENT),
         (BUTTON_LL , CONTROL          , ()): lambda: self.open(FOLDER_PARENT),
         (BUTTON_M  , 0                , ()): lambda: self.open(FOLDER_PARENT),
         (BUTTON_M  , CONTROL          , ()): lambda: self.open(FOLDER_PARENT),
         (WHEEL_UP  , RBUTTON          , ()): lambda: self.open(FOLDER_PARENT),
         (WHEEL_DOWN, RBUTTON          , ()): lambda: self.open(FOLDER_PARENT),
         (BUTTON_R  , 0          , (NORTH,)): lambda: self.open(FOLDER_PARENT),
         (BUTTON_R  , 0          , (WEST,) ): lambda: self.open(FOLDER_BACK),
         (BUTTON_R  , 0          , (EAST,) ): lambda: self.open(FOLDER_FORWARD),
         (BUTTON_R  , CONTROL    , (NORTH,)): lambda: self.open(FOLDER_PARENT),
         (BUTTON_R  , CONTROL    , (WEST,) ): lambda: self.open(FOLDER_BACK),
         (BUTTON_R  , CONTROL    , (EAST,) ): lambda: self.open(FOLDER_FORWARD),
         (BUTTON_R  , 0          , (SOUTH,)): self.close
    })
